pub enum ToolCommand {
Show 14 variants
ScanConsensusCommits {
db_path: String,
start_commit: Option<u32>,
end_commit: Option<u32>,
},
LockedObject {
id: Option<ObjectID>,
address: Option<SuiAddress>,
fullnode_rpc_url: String,
rescue: bool,
},
FetchObject {
id: ObjectID,
version: Option<u64>,
validator: Option<AuthorityName>,
fullnode_rpc_url: String,
verbosity: Verbosity,
concise_no_header: bool,
},
FetchTransaction {
fullnode_rpc_url: String,
digest: TransactionDigest,
show_input_tx: bool,
},
DbTool {
db_path: String,
cmd: Option<DbToolCommand>,
},
DumpPackages {
rpc_url: String,
output_dir: PathBuf,
before_checkpoint: Option<u64>,
verbose: bool,
},
DumpValidators {
genesis: PathBuf,
concise: bool,
},
DumpGenesis {
genesis: PathBuf,
},
FetchCheckpoint {
fullnode_rpc_url: String,
sequence_number: Option<CheckpointSequenceNumber>,
},
Anemo {
args: Args,
},
RestoreFromDBCheckpoint {
config_path: PathBuf,
db_checkpoint_path: PathBuf,
},
DownloadFormalSnapshot {Show 15 fields
epoch: Option<u64>,
genesis: PathBuf,
path: PathBuf,
num_parallel_downloads: Option<usize>,
num_parallel_chunks: usize,
verify: Option<SnapshotVerifyMode>,
network: Chain,
snapshot_bucket: Option<String>,
snapshot_bucket_type: Option<ObjectStoreType>,
snapshot_path: Option<PathBuf>,
no_sign_request: bool,
latest: bool,
verbose: bool,
max_retries: usize,
metrics_port: u16,
},
Replay {
rpc_url: Option<String>,
safety_checks: bool,
use_authority: bool,
cfg_path: Option<PathBuf>,
chain: Option<String>,
cmd: ReplayToolCommand,
},
DbShell(DbShellArgs),
}Variants
ScanConsensusCommits
LockedObject
Inspect if a specific object is or all gas objects owned by an address are locked by validators
Fields
address: Option<SuiAddress>Either id or address must be provided If provided, check all gas objects owned by this account
FetchObject
Fetch the same object from all validators
Fields
validator: Option<AuthorityName>verbosity: VerbosityConcise mode groups responses by results. prints tabular output suitable for processing with unix tools. For instance, to quickly check that all validators agree on the history of an object:
$ sui-tool fetch-object --id 0x260efde76ebccf57f4c5e951157f5c361cde822c \
--genesis $HOME/.sui/sui_config/genesis.blob \
--verbosity concise --concise-no-headerFetchTransaction
Fetch the effects association with transaction digest
Fields
digest: TransactionDigestDbTool
Tool to read validator & node db.
DumpPackages
Download all packages to the local filesystem from a GraphQL service. Each package gets its own sub-directory, named for its ID on chain and version containing two metadata files (linkage.json and origins.json), a file containing the overall object and a file for every module it contains. Each module file is named for its module name, with a .mv suffix, and contains Move bytecode (suitable for passing into a disassembler).
Fields
output_dir: PathBufPath to a non-existent directory that can be created and filled with package information.
DumpValidators
DumpGenesis
FetchCheckpoint
Fetch authenticated checkpoint information at a specific sequence number. If sequence number is not specified, get the latest authenticated checkpoint.
Anemo
Fields
args: ArgsRestoreFromDBCheckpoint
DownloadFormalSnapshot
for protocol versions supporting commit_root_state_digest. For mainnet, this is
epoch 20+, and for testnet this is epoch 12+
Fields
num_parallel_downloads: Option<usize>Number of parallel downloads to perform. Defaults to 50, max 200.
verify: Option<SnapshotVerifyMode>Verification mode to employ.
network: ChainNetwork to download snapshot for. Defaults to “mainnet”.
If --snapshot-bucket or --archive-bucket is not specified,
the value of this flag is used to construct default bucket names.
snapshot_bucket: Option<String>Snapshot bucket name. If not specified, defaults are
based on value of --network flag.
snapshot_bucket_type: Option<ObjectStoreType>Snapshot bucket type
snapshot_path: Option<PathBuf>Path to snapshot directory on local filesystem.
Only applicable if --snapshot-bucket-type is “file”.
latest: boolDownload snapshot of the latest available epoch.
If --epoch is specified, then this flag gets ignored.
verbose: boolIf false (default), log level will be overridden to “off”, and output will be reduced to necessary status information.
Replay
DbShell(DbShellArgs)
Interactive shell for navigating the validator database.
Implementations
Sourceimpl ToolCommand
impl ToolCommand